/*
version: $Id: error_handle.c,v 5.123 1995/01/18 01:24:58 hitman Exp $
purpose: Display errors to the screen for various errors.
updates: All updates are handled by RCS
*/

#include <stdio.h>

#ifndef __MSDOS__
#	include "hsh_glob.h"
#	include "hshgen_s.h"
#else				/* not_MSDOS */
#	include "..\src\hsh_glob.h"
#	include "..\src\hshgen_s.h"
#endif				/* MSDOS */

/* Define functions and procedures. */
int             error_handle(_character * Character);

int 
error_handle(_character * Character)
{
#ifdef DEBUG
	fprintf(stderr, "** %s: **\n", __FILE__);
#endif
	fprintf(stderr, "ERROR!");

	return (RET_NORMAL);
}				/* error_handle */
