@echo off

rem # [$Id$]
rem # purpose: cleanup unwanted object files.

echo "Cleaning..."

echo "  Source Objects,"
echo "          Directory: ..\src\"
del ..\src\*.obj 
echo "          Directory: ..\src\bbs_fn-s\"
del ..\src\bbs_fn-s\*.obj

echo "  Source Backup Files,"
echo "          Directory: ..\src\"
del ..\src\*.bak 
echo "          Directory: ..\src\bbs_fn-s\"
del ..\src\bbs_fn-s\*.bak

echo "Done"
